pandas.Panel4D
==============

.. currentmodule:: pandas

.. autoclass:: Panel4D

   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      
      Panel4D.abs
      Panel4D.add
      Panel4D.add_prefix
      Panel4D.add_suffix
      Panel4D.align
      Panel4D.apply
      Panel4D.as_blocks
      Panel4D.as_matrix
      Panel4D.asfreq
      Panel4D.astype
      Panel4D.at_time
      Panel4D.between_time
      Panel4D.bfill
      Panel4D.bool
      Panel4D.clip
      Panel4D.clip_lower
      Panel4D.clip_upper
      Panel4D.compound
      Panel4D.conform
      Panel4D.consolidate
      Panel4D.convert_objects
      Panel4D.copy
      Panel4D.count
      Panel4D.cummax
      Panel4D.cummin
      Panel4D.cumprod
      Panel4D.cumsum
      Panel4D.div
      Panel4D.divide
      Panel4D.drop
      Panel4D.dropna
      Panel4D.eq
      Panel4D.ffill
      Panel4D.fillna
      Panel4D.filter
      Panel4D.first
      Panel4D.floordiv
      Panel4D.fromDict
      Panel4D.from_dict
      Panel4D.ge
      Panel4D.get
      Panel4D.get_dtype_counts
      Panel4D.get_ftype_counts
      Panel4D.get_value
      Panel4D.get_values
      Panel4D.groupby
      Panel4D.gt
      Panel4D.head
      Panel4D.interpolate
      Panel4D.isnull
      Panel4D.iteritems
      Panel4D.iterkv
      Panel4D.join
      Panel4D.keys
      Panel4D.kurt
      Panel4D.kurtosis
      Panel4D.last
      Panel4D.le
      Panel4D.load
      Panel4D.lt
      Panel4D.mad
      Panel4D.major_xs
      Panel4D.mask
      Panel4D.max
      Panel4D.mean
      Panel4D.median
      Panel4D.min
      Panel4D.minor_xs
      Panel4D.mod
      Panel4D.mul
      Panel4D.multiply
      Panel4D.ne
      Panel4D.notnull
      Panel4D.pct_change
      Panel4D.pop
      Panel4D.pow
      Panel4D.prod
      Panel4D.product
      Panel4D.radd
      Panel4D.rdiv
      Panel4D.reindex
      Panel4D.reindex_axis
      Panel4D.reindex_like
      Panel4D.rename
      Panel4D.rename_axis
      Panel4D.replace
      Panel4D.resample
      Panel4D.rfloordiv
      Panel4D.rmod
      Panel4D.rmul
      Panel4D.rpow
      Panel4D.rsub
      Panel4D.rtruediv
      Panel4D.save
      Panel4D.select
      Panel4D.set_value
      Panel4D.shift
      Panel4D.skew
      Panel4D.sort_index
      Panel4D.squeeze
      Panel4D.std
      Panel4D.sub
      Panel4D.subtract
      Panel4D.sum
      Panel4D.swapaxes
      Panel4D.swaplevel
      Panel4D.tail
      Panel4D.take
      Panel4D.toLong
      Panel4D.to_clipboard
      Panel4D.to_dense
      Panel4D.to_excel
      Panel4D.to_frame
      Panel4D.to_hdf
      Panel4D.to_json
      Panel4D.to_long
      Panel4D.to_msgpack
      Panel4D.to_pickle
      Panel4D.to_sparse
      Panel4D.transpose
      Panel4D.truediv
      Panel4D.truncate
      Panel4D.tshift
      Panel4D.tz_convert
      Panel4D.tz_localize
      Panel4D.update
      Panel4D.var
      Panel4D.where
      Panel4D.xs




   


..
   HACK -- the point here is that we don't want this to appear in the output, but the autosummary should still generate the pages.
   .. autosummary::
      :toctree:
      
      Panel4D.at
      Panel4D.axes
      Panel4D.blocks
      Panel4D.dtypes
      Panel4D.empty
      Panel4D.ftypes
      Panel4D.iat
      Panel4D.iloc
      Panel4D.is_copy
      Panel4D.ix
      Panel4D.loc
      Panel4D.ndim
      Panel4D.shape
      Panel4D.values


